==> esp32s3-0.1.0.crate: esp32s3-0.1.0/src/extmem/dcache_ctrl1.rs <==
#[doc = "Register `DCACHE_CTRL1` reader"]
pub struct R(crate::R<DCACHE_CTRL1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DCACHE_CTRL1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<DCACHE_CTRL1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<DCACHE_CTRL1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DCACHE_CTRL1` writer"]
pub struct W(crate::W<DCACHE_CTRL1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DCACHE_CTRL1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<DCACHE_CTRL1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<DCACHE_CTRL1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `DCACHE_SHUT_CORE0_BUS` reader - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE0_BUS_R(crate::FieldReader<bool, bool>);
impl DCACHE_SHUT_CORE0_BUS_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        DCACHE_SHUT_CORE0_BUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DCACHE_SHUT_CORE0_BUS_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DCACHE_SHUT_CORE0_BUS` writer - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE0_BUS_W<'a> {
    w: &'a mut W,
}
impl<'a> DCACHE_SHUT_CORE0_BUS_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !0x01) | (value as u32 & 0x01);
        self.w
    }
}
#[doc = "Field `DCACHE_SHUT_CORE1_BUS` reader - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE1_BUS_R(crate::FieldReader<bool, bool>);
impl DCACHE_SHUT_CORE1_BUS_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        DCACHE_SHUT_CORE1_BUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DCACHE_SHUT_CORE1_BUS_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DCACHE_SHUT_CORE1_BUS` writer - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE1_BUS_W<'a> {
    w: &'a mut W,
}
impl<'a> DCACHE_SHUT_CORE1_BUS_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(0x01 << 1)) | ((value as u32 & 0x01) << 1);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core0_bus(&self) -> DCACHE_SHUT_CORE0_BUS_R {
        DCACHE_SHUT_CORE0_BUS_R::new((self.bits & 0x01) != 0)
    }
    #[doc = "Bit 1 - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core1_bus(&self) -> DCACHE_SHUT_CORE1_BUS_R {
        DCACHE_SHUT_CORE1_BUS_R::new(((self.bits >> 1) & 0x01) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core0_bus(&mut self) -> DCACHE_SHUT_CORE0_BUS_W {
        DCACHE_SHUT_CORE0_BUS_W { w: self }
    }
    #[doc = "Bit 1 - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core1_bus(&mut self) -> DCACHE_SHUT_CORE1_BUS_W {
        DCACHE_SHUT_CORE1_BUS_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "******* Description ***********\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dcache_ctrl1]
(index.html) module"]
pub struct DCACHE_CTRL1_SPEC;
impl crate::RegisterSpec for DCACHE_CTRL1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dcache_ctrl1::R]
(R) reader structure"]
impl crate::Readable for DCACHE_CTRL1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dcache_ctrl1::W]
(W) writer structure"]
impl crate::Writable for DCACHE_CTRL1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DCACHE_CTRL1 to value 0x03"]
impl crate::Resettable for DCACHE_CTRL1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x03
    }
}

==> esp32s3-0.2.0.crate: esp32s3-0.2.0/src/extmem/dcache_ctrl1.rs <==
#[doc = "Register `DCACHE_CTRL1` reader"]
pub struct R(crate::R<DCACHE_CTRL1_SPEC>);
impl core::ops::Deref for R {
    type Target = crate::R<DCACHE_CTRL1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl From<crate::R<DCACHE_CTRL1_SPEC>> for R {
    #[inline(always)]
    fn from(reader: crate::R<DCACHE_CTRL1_SPEC>) -> Self {
        R(reader)
    }
}
#[doc = "Register `DCACHE_CTRL1` writer"]
pub struct W(crate::W<DCACHE_CTRL1_SPEC>);
impl core::ops::Deref for W {
    type Target = crate::W<DCACHE_CTRL1_SPEC>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
impl core::ops::DerefMut for W {
    #[inline(always)]
    fn deref_mut(&mut self) -> &mut Self::Target {
        &mut self.0
    }
}
impl From<crate::W<DCACHE_CTRL1_SPEC>> for W {
    #[inline(always)]
    fn from(writer: crate::W<DCACHE_CTRL1_SPEC>) -> Self {
        W(writer)
    }
}
#[doc = "Field `DCACHE_SHUT_CORE0_BUS` reader - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE0_BUS_R(crate::FieldReader<bool, bool>);
impl DCACHE_SHUT_CORE0_BUS_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        DCACHE_SHUT_CORE0_BUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DCACHE_SHUT_CORE0_BUS_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DCACHE_SHUT_CORE0_BUS` writer - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE0_BUS_W<'a> {
    w: &'a mut W,
}
impl<'a> DCACHE_SHUT_CORE0_BUS_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !1) | (value as u32 & 1);
        self.w
    }
}
#[doc = "Field `DCACHE_SHUT_CORE1_BUS` reader - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE1_BUS_R(crate::FieldReader<bool, bool>);
impl DCACHE_SHUT_CORE1_BUS_R {
    #[inline(always)]
    pub(crate) fn new(bits: bool) -> Self {
        DCACHE_SHUT_CORE1_BUS_R(crate::FieldReader::new(bits))
    }
}
impl core::ops::Deref for DCACHE_SHUT_CORE1_BUS_R {
    type Target = crate::FieldReader<bool, bool>;
    #[inline(always)]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}
#[doc = "Field `DCACHE_SHUT_CORE1_BUS` writer - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
pub struct DCACHE_SHUT_CORE1_BUS_W<'a> {
    w: &'a mut W,
}
impl<'a> DCACHE_SHUT_CORE1_BUS_W<'a> {
    #[doc = r"Sets the field bit"]
    #[inline(always)]
    pub fn set_bit(self) -> &'a mut W {
        self.bit(true)
    }
    #[doc = r"Clears the field bit"]
    #[inline(always)]
    pub fn clear_bit(self) -> &'a mut W {
        self.bit(false)
    }
    #[doc = r"Writes raw bits to the field"]
    #[inline(always)]
    pub fn bit(self, value: bool) -> &'a mut W {
        self.w.bits = (self.w.bits & !(1 << 1)) | ((value as u32 & 1) << 1);
        self.w
    }
}
impl R {
    #[doc = "Bit 0 - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core0_bus(&self) -> DCACHE_SHUT_CORE0_BUS_R {
        DCACHE_SHUT_CORE0_BUS_R::new((self.bits & 1) != 0)
    }
    #[doc = "Bit 1 - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core1_bus(&self) -> DCACHE_SHUT_CORE1_BUS_R {
        DCACHE_SHUT_CORE1_BUS_R::new(((self.bits >> 1) & 1) != 0)
    }
}
impl W {
    #[doc = "Bit 0 - The bit is used to disable core0 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core0_bus(&mut self) -> DCACHE_SHUT_CORE0_BUS_W {
        DCACHE_SHUT_CORE0_BUS_W { w: self }
    }
    #[doc = "Bit 1 - The bit is used to disable core1 dbus, 0: enable, 1: disable"]
    #[inline(always)]
    pub fn dcache_shut_core1_bus(&mut self) -> DCACHE_SHUT_CORE1_BUS_W {
        DCACHE_SHUT_CORE1_BUS_W { w: self }
    }
    #[doc = "Writes raw bits to the register."]
    #[inline(always)]
    pub unsafe fn bits(&mut self, bits: u32) -> &mut Self {
        self.0.bits(bits);
        self
    }
}
#[doc = "******* Description ***********\n\nThis register you can [`read`]
(crate::generic::Reg::read), [`write_with_zero`]
(crate::generic::Reg::write_with_zero), [`reset`]
(crate::generic::Reg::reset), [`write`]
(crate::generic::Reg::write), [`modify`]
(crate::generic::Reg::modify). See [API]
(https://docs.rs/svd2rust/#read--modify--write-api).\n\nFor information about available fields see [dcache_ctrl1]
(index.html) module"]
pub struct DCACHE_CTRL1_SPEC;
impl crate::RegisterSpec for DCACHE_CTRL1_SPEC {
    type Ux = u32;
}
#[doc = "`read()` method returns [dcache_ctrl1::R]
(R) reader structure"]
impl crate::Readable for DCACHE_CTRL1_SPEC {
    type Reader = R;
}
#[doc = "`write(|w| ..)` method takes [dcache_ctrl1::W]
(W) writer structure"]
impl crate::Writable for DCACHE_CTRL1_SPEC {
    type Writer = W;
}
#[doc = "`reset()` method sets DCACHE_CTRL1 to value 0x03"]
impl crate::Resettable for DCACHE_CTRL1_SPEC {
    #[inline(always)]
    fn reset_value() -> Self::Ux {
        0x03
    }
}
